@@ -513,7 +513,7 @@ Output, if any, is displayed.  The message is not altered."
 	(display-buffer buffer))))
 
 (defun vm-print-message (&optional count)
-  "Print the current message
+  "Print the current message.
 Prefix arg N means print the current message and the next N - 1 messages.
 Prefix arg -N means print the current message and the previous N - 1 messages.
 
